@@ -7,6 +7,7 @@ import SoftLayer
 from SoftLayer.CLI import environment
 from SoftLayer.CLI import formatting
 from SoftLayer.CLI import helpers
+from SoftLayer import utils
 
 
 @click.command()
@@ -35,6 +36,8 @@ def cli(env, identifier, no_vs, no_hardware):
                    '%s/%s' % (subnet['networkIdentifier'],
                               str(subnet['cidr']))])
     table.add_row(['subnet type', subnet['subnetType']])
+    table.add_row(['network space',
+                   utils.lookup(subnet, 'networkVlan', 'networkSpace')])
     table.add_row(['gateway', subnet.get('gateway', formatting.blank())])
     table.add_row(['broadcast',
                    subnet.get('broadcastAddress', formatting.blank())])
@@ -44,26 +47,24 @@ def cli(env, identifier, no_vs, no_hardware):
 
     if not no_vs:
         if subnet['virtualGuests']:
-            vs_table = formatting.Table(['Hostname', 'Domain', 'IP'])
-            vs_table.align['Hostname'] = 'r'
-            vs_table.align['IP'] = 'l'
+            vs_table = formatting.Table(['hostname', 'domain', 'public_ip', 'private_ip'])
             for vsi in subnet['virtualGuests']:
                 vs_table.add_row([vsi['hostname'],
                                   vsi['domain'],
-                                  vsi.get('primaryIpAddress')])
+                                  vsi.get('primaryIpAddress'),
+                                  vsi.get('primaryBackendIpAddress')])
             table.add_row(['vs', vs_table])
         else:
             table.add_row(['vs', 'none'])
 
     if not no_hardware:
         if subnet['hardware']:
-            hw_table = formatting.Table(['Hostname', 'Domain', 'IP'])
-            hw_table.align['Hostname'] = 'r'
-            hw_table.align['IP'] = 'l'
+            hw_table = formatting.Table(['hostname', 'domain', 'public_ip', 'private_ip'])
             for hardware in subnet['hardware']:
                 hw_table.add_row([hardware['hostname'],
                                   hardware['domain'],
-                                  hardware.get('primaryIpAddress')])
+                                  hardware.get('primaryIpAddress'),
+                                  hardware.get('primaryBackendIpAddress')])
             table.add_row(['hardware', hw_table])
         else:
             table.add_row(['hardware', 'none'])
