@@ -1,3 +1,6 @@
+# -*- coding: UTF-8 -*-
+
+# # pylint: disable=bad-continuation
 getPrivateBlockDeviceTemplateGroups = [{
     'accountId': 1234,
     'blockDevices': [],
@@ -5,19 +8,23 @@ getPrivateBlockDeviceTemplateGroups = [{
     'globalIdentifier': 'E6DBD73B-1651-4B28-BCBA-A11DF7C9D79E',
     'id': 200,
     'name': 'test_image',
-    'parentId': ''
+    'parentId': '',
+    'publicFlag': False,
 }, {
     'accountId': 1234,
     'blockDevices': [],
     'createDate': '2013-12-05T21:53:03-06:00',
     'globalIdentifier': 'F9329795-4220-4B0A-B970-C86B950667FA',
     'id': 201,
-    'name': 'private_image2',
-    'parentId': ''
+    # 'name': 'private_image2',
+    'name': u'a¬ሴ€耀',
+    'parentId': '',
+    'publicFlag': False,
 }]
 
 getVirtualGuests = [{
     'id': 100,
+    'metricTrackingObjectId': 1,
     'hostname': 'vs-test1',
     'domain': 'test.sftlyr.ws',
     'fullyQualifiedDomainName': 'vs-test1.test.sftlyr.ws',
@@ -45,6 +52,7 @@ getVirtualGuests = [{
     },
 }, {
     'id': 104,
+    'metricTrackingObjectId': 2,
     'hostname': 'vs-test2',
     'domain': 'test.sftlyr.ws',
     'fullyQualifiedDomainName': 'vs-test2.test.sftlyr.ws',
@@ -69,6 +77,7 @@ getVirtualGuests = [{
             }
         }
     },
+    'virtualRack': {'id': 1, 'bandwidthAllotmentTypeId': 2},
 }]
 
 getMonthlyVirtualGuests = [vs for vs in getVirtualGuests
@@ -76,9 +85,9 @@ getMonthlyVirtualGuests = [vs for vs in getVirtualGuests
 getHourlyVirtualGuests = [vs for vs in getVirtualGuests
                           if vs['hourlyBillingFlag']]
 
-
 getHardware = [{
     'id': 1000,
+    'metricTrackingObject': {'id': 3},
     'globalIdentifier': '1a2b3c-1701',
     'datacenter': {'id': 50, 'name': 'TEST00',
                    'description': 'Test Data Center'},
@@ -139,6 +148,7 @@ getHardware = [{
     },
 }, {
     'id': 1001,
+    'metricTrackingObject': {'id': 4},
     'globalIdentifier': '1a2b3c-1702',
     'datacenter': {'name': 'TEST00',
                    'description': 'Test Data Center'},
@@ -183,6 +193,7 @@ getHardware = [{
     ]
 }, {
     'id': 1002,
+    'metricTrackingObject': {'id': 5},
     'datacenter': {'name': 'TEST00',
                    'description': 'Test Data Center'},
     'billingItem': {
@@ -256,7 +267,8 @@ getObject = {
             "statusId": 4,
             "accountId": 1234
         }
-    ]
+    ],
+    'accountId': 1234
 }
 
 getRwhoisData = {
@@ -304,9 +316,14 @@ getSubnets = [
     {
         'id': '100',
         'networkIdentifier': '10.0.0.1',
+        'cidr': '/24',
+        'networkVlanId': 123,
         'datacenter': {'name': 'dal00'},
         'version': 4,
-        'subnetType': 'PRIMARY'
+        'subnetType': 'PRIMARY',
+        'ipAddressCount': 10,
+        'virtualGuests': [],
+        'hardware': []
     }]
 
 getSshKeys = [{'id': '100', 'label': 'Test 1'},
@@ -467,6 +484,8 @@ getNasNetworkStorage = [{
     'username': 'user',
     'password': 'pass',
     'serviceResourceBackendIpAddress': '127.0.0.1',
+    'storageType': {'keyName': 'ENDURANCE_STORAGE'},
+    'fileNetworkMountAddress': '127.0.0.1:/TEST',
 }]
 
 getActiveQuotes = [{
@@ -475,7 +494,6 @@ getActiveQuotes = [{
     'quoteKey': '1234test4321',
 }]
 
-
 getOrders = [{
     'id': 1234,
     'resourceType': '1 x 2.0 GHz Core',
@@ -523,9 +541,104 @@ getIscsiNetworkStorage = [{
     'notes': """{'status': 'available'}""",
     'password': '',
     'serviceProviderId': 1,
-    'serviceResource': {'datacenter': {'id': 449500}},
+    'serviceResource': {'datacenter': {'name': 'dal05', 'id': 449500}},
     'serviceResourceBackendIpAddress': '10.1.2.3',
     'serviceResourceName': 'Storage Type 01 Aggregate staaspar0101_pc01',
     'username': 'username',
     'storageType': {'keyName': 'ENDURANCE_STORAGE'},
 }]
+
+getVirtualDedicatedRacks = [{
+    'id': 1,
+    'name': 'my first pool',
+    'metricTrackingObjectId': 10,
+}]
+
+getDedicatedHosts = [{
+    'datacenter': {
+        'name': 'dal05'
+    },
+    'memoryCapacity': 242,
+    'name': 'test-dedicated',
+    'diskCapacity': 1200,
+    'guestCount': 1,
+    'cpuCount': 56,
+    'id': 12345
+}]
+
+
+getUsers = [
+    {'displayName': 'ChristopherG',
+     'hardwareCount': 138,
+     'id': 11100,
+     'userStatus': {'name': 'Active'},
+     'username': 'SL1234',
+     'virtualGuestCount': 99},
+    {'displayName': 'PulseL',
+     'hardwareCount': 100,
+     'id': 11111,
+     'userStatus': {'name': 'Active'},
+     'username': 'sl1234-abob',
+     'virtualGuestCount': 99}
+]
+
+getReservedCapacityGroups = [
+    {
+        'accountId': 1234,
+        'backendRouterId': 1411193,
+        'createDate': '2018-09-24T16:33:09-06:00',
+        'id': 3103,
+        'modifyDate': '',
+        'name': 'test-capacity',
+        'availableInstanceCount': 1,
+        'instanceCount': 2,
+        'occupiedInstanceCount': 1,
+        'backendRouter': {
+            'accountId': 1,
+            'bareMetalInstanceFlag': 0,
+            'domain': 'softlayer.com',
+            'fullyQualifiedDomainName': 'bcr02a.dal13.softlayer.com',
+            'hardwareStatusId': 5,
+            'hostname': 'bcr02a.dal13',
+            'id': 1411193,
+            'notes': '',
+            'provisionDate': '',
+            'serviceProviderId': 1,
+            'serviceProviderResourceId': '',
+            'primaryIpAddress': '10.0.144.28',
+            'datacenter': {
+                'id': 1854895,
+                'longName': 'Dallas 13',
+                'name': 'dal13',
+                'statusId': 2
+            },
+            'hardwareFunction': {
+                'code': 'ROUTER',
+                'description': 'Router',
+                'id': 1
+            },
+            'topLevelLocation': {
+                'id': 1854895,
+                'longName': 'Dallas 13',
+                'name': 'dal13',
+                'statusId': 2
+            }
+        },
+        'instances': [
+            {
+                'id': 3501,
+                'billingItem': {
+                    'description': 'B1.1x2 (1 Year Term)',
+                    'hourlyRecurringFee': '.032'
+                }
+            },
+            {
+                'id': 3519,
+                'billingItem': {
+                    'description': 'B1.1x2 (1 Year Term)',
+                    'hourlyRecurringFee': '.032'
+                }
+            }
+        ]
+    }
+]
