@@ -9,12 +9,13 @@
 """
 from SoftLayer.managers.block import BlockStorageManager
 from SoftLayer.managers.cdn import CDNManager
+from SoftLayer.managers.dedicated_host import DedicatedHostManager
 from SoftLayer.managers.dns import DNSManager
 from SoftLayer.managers.file import FileStorageManager
 from SoftLayer.managers.firewall import FirewallManager
 from SoftLayer.managers.hardware import HardwareManager
 from SoftLayer.managers.image import ImageManager
-from SoftLayer.managers.iscsi import ISCSIManager
+from SoftLayer.managers.ipsec import IPSECManager
 from SoftLayer.managers.load_balancer import LoadBalancerManager
 from SoftLayer.managers.messaging import MessagingManager
 from SoftLayer.managers.metadata import MetadataManager
@@ -24,17 +25,22 @@ from SoftLayer.managers.ordering import OrderingManager
 from SoftLayer.managers.sshkey import SshKeyManager
 from SoftLayer.managers.ssl import SSLManager
 from SoftLayer.managers.ticket import TicketManager
+from SoftLayer.managers.user import UserManager
 from SoftLayer.managers.vs import VSManager
+from SoftLayer.managers.vs_capacity import CapacityManager
+
 
 __all__ = [
     'BlockStorageManager',
+    'CapacityManager',
     'CDNManager',
+    'DedicatedHostManager',
     'DNSManager',
     'FileStorageManager',
     'FirewallManager',
     'HardwareManager',
     'ImageManager',
-    'ISCSIManager',
+    'IPSECManager',
     'LoadBalancerManager',
     'MessagingManager',
     'MetadataManager',
@@ -44,5 +50,6 @@ __all__ = [
     'SshKeyManager',
     'SSLManager',
     'TicketManager',
+    'UserManager',
     'VSManager',
 ]
