@@ -7,6 +7,8 @@
 """
 # pylint: disable=no-self-use
 
+from re import match
+
 from SoftLayer import exceptions
 
 CATEGORY_MASK = '''id,
@@ -32,6 +34,7 @@ class OrderingManager(object):
         self.package_svc = client['Product_Package']
         self.order_svc = client['Product_Order']
         self.billing_svc = client['Billing_Order']
+        self.package_preset = client['Product_Package_Preset']
 
     def get_packages_of_type(self, package_types, mask=None):
         """Get packages that match a certain type.
@@ -297,7 +300,18 @@ class OrderingManager(object):
     def get_preset_by_key(self, package_keyname, preset_keyname, mask=None):
         """Gets a single preset with the given key."""
         preset_operation = '_= %s' % preset_keyname
-        _filter = {'activePresets': {'keyName': {'operation': preset_operation}}}
+        _filter = {
+            'activePresets': {
+                'keyName': {
+                    'operation': preset_operation
+                }
+            },
+            'accountRestrictedActivePresets': {
+                'keyName': {
+                    'operation': preset_operation
+                }
+            }
+        }
 
         presets = self.list_presets(package_keyname, mask=mask, filter=_filter)
 
@@ -308,7 +322,7 @@ class OrderingManager(object):
 
         return presets[0]
 
-    def get_price_id_list(self, package_keyname, item_keynames):
+    def get_price_id_list(self, package_keyname, item_keynames, core=None):
         """Converts a list of item keynames to a list of price IDs.
 
         This function is used to convert a list of item keynames into
@@ -317,14 +331,16 @@ class OrderingManager(object):
 
         :param str package_keyname: The package associated with the prices
         :param list item_keynames: A list of item keyname strings
+        :param str core: preset guest core capacity.
         :returns: A list of price IDs associated with the given item
                   keynames in the given package
 
         """
-        mask = 'id, keyName, prices'
+        mask = 'id, itemCategory, keyName, prices[categories]'
         items = self.list_items(package_keyname, mask=mask)
 
         prices = []
+        gpu_number = -1
         for item_keyname in item_keynames:
             try:
                 # Need to find the item in the package that has a matching
@@ -340,12 +356,64 @@ class OrderingManager(object):
             # because that is the most generic price. verifyOrder/placeOrder
             # can take that ID and create the proper price for us in the location
             # in which the order is made
-            price_id = [p['id'] for p in matching_item['prices']
-                        if p['locationGroupId'] == ''][0]
+            if matching_item['itemCategory']['categoryCode'] != "gpu0":
+                price_id = self.get_item_price_id(core, matching_item['prices'])
+            else:
+                # GPU items has two generic prices and they are added to the list
+                # according to the number of gpu items added in the order.
+                gpu_number += 1
+                price_id = [p['id'] for p in matching_item['prices']
+                            if not p['locationGroupId']
+                            and p['categories'][0]['categoryCode'] == "gpu" + str(gpu_number)][0]
+
             prices.append(price_id)
 
         return prices
 
+    @staticmethod
+    def get_item_price_id(core, prices):
+        """get item price id"""
+        price_id = None
+        for price in prices:
+            if not price['locationGroupId']:
+                capacity_min = int(price.get('capacityRestrictionMinimum', -1))
+                capacity_max = int(price.get('capacityRestrictionMaximum', -1))
+                # return first match if no restirction, or no core to check
+                if capacity_min == -1 or core is None:
+                    price_id = price['id']
+                # this check is mostly to work nicely with preset configs
+                elif capacity_min <= int(core) <= capacity_max:
+                    price_id = price['id']
+        return price_id
+
+    def get_preset_prices(self, preset):
+        """Get preset item prices.
+
+        Retrieve a SoftLayer_Product_Package_Preset record.
+
+        :param int preset: preset identifier.
+        :returns: A list of price IDs associated with the given preset_id.
+
+        """
+        mask = 'mask[prices[item]]'
+
+        prices = self.package_preset.getObject(id=preset, mask=mask)
+        return prices
+
+    def get_item_prices(self, package_id):
+        """Get item prices.
+
+        Retrieve a SoftLayer_Product_Package item prices record.
+
+        :param int package_id: package identifier.
+        :returns: A list of price IDs associated with the given package.
+
+        """
+        mask = 'mask[pricingLocationGroup[locations]]'
+
+        prices = self.package_svc.getItemPrices(id=package_id, mask=mask)
+        return prices
+
     def verify_order(self, package_keyname, location, item_keynames, complex_type=None,
                      hourly=True, preset_keyname=None, extras=None, quantity=1):
         """Verifies an order with the given package and prices.
@@ -407,6 +475,39 @@ class OrderingManager(object):
                                     extras=extras, quantity=quantity)
         return self.order_svc.placeOrder(order)
 
+    def place_quote(self, package_keyname, location, item_keynames, complex_type=None,
+                    preset_keyname=None, extras=None, quantity=1, quote_name=None, send_email=False):
+        """Place a quote with the given package and prices.
+
+        This function takes in parameters needed for an order and places the quote.
+
+        :param str package_keyname: The keyname for the package being ordered
+        :param str location: The datacenter location string for ordering (Ex: DALLAS13)
+        :param list item_keynames: The list of item keyname strings to order. To see list of
+                                   possible keynames for a package, use list_items()
+                                   (or `slcli order item-list`)
+        :param str complex_type: The complex type to send with the order. Typically begins
+                                 with `SoftLayer_Container_Product_Order_`.
+        :param string preset_keyname: If needed, specifies a preset to use for that package.
+                                      To see a list of possible keynames for a package, use
+                                      list_preset() (or `slcli order preset-list`)
+        :param dict extras: The extra data for the order in dictionary format.
+                            Example: A VSI order requires hostname and domain to be set, so
+                            extras will look like the following:
+                            {'virtualGuests': [{'hostname': 'test', domain': 'softlayer.com'}]}
+        :param int quantity: The number of resources to order
+        :param string quote_name: A custom name to be assigned to the quote (optional).
+        :param bool send_email: This flag indicates that the quote should be sent to the email
+                                address associated with the account or order.
+        """
+        order = self.generate_order(package_keyname, location, item_keynames, complex_type=complex_type,
+                                    hourly=False, preset_keyname=preset_keyname, extras=extras, quantity=quantity)
+
+        order['quoteName'] = quote_name
+        order['sendQuoteEmailFlag'] = send_email
+
+        return self.order_svc.placeQuote(order)
+
     def generate_order(self, package_keyname, location, item_keynames, complex_type=None,
                        hourly=True, preset_keyname=None, extras=None, quantity=1):
         """Generates an order with the given package and prices.
@@ -432,6 +533,7 @@ class OrderingManager(object):
         :param int quantity: The number of resources to order
 
         """
+        container = {}
         order = {}
         extras = extras or {}
 
@@ -443,21 +545,29 @@ class OrderingManager(object):
         #                                    'domain': 'softlayer.com'}]}
         order.update(extras)
         order['packageId'] = package['id']
-        order['location'] = location
+        order['location'] = self.get_location_id(location)
         order['quantity'] = quantity
         order['useHourlyPricing'] = hourly
 
+        preset_core = None
         if preset_keyname:
             preset_id = self.get_preset_by_key(package_keyname, preset_keyname)['id']
+            preset_items = self.get_preset_prices(preset_id)
+            for item in preset_items['prices']:
+                if item['item']['itemCategory']['categoryCode'] == "guest_core":
+                    preset_core = item['item']['capacity']
             order['presetId'] = preset_id
 
         if not complex_type:
             raise exceptions.SoftLayerError("A complex type must be specified with the order")
         order['complexType'] = complex_type
 
-        price_ids = self.get_price_id_list(package_keyname, item_keynames)
+        price_ids = self.get_price_id_list(package_keyname, item_keynames, preset_core)
         order['prices'] = [{'id': price_id} for price_id in price_ids]
-        return order
+
+        container['orderContainers'] = [order]
+
+        return container
 
     def package_locations(self, package_keyname):
         """List datacenter locations for a package keyname
@@ -471,3 +581,23 @@ class OrderingManager(object):
 
         regions = self.package_svc.getRegions(id=package['id'], mask=mask)
         return regions
+
+    def get_location_id(self, location):
+        """Finds the location ID of a given datacenter
+
+        This is mostly used so either a dc name, or regions keyname can be used when ordering
+        :param str location: Region Keyname (DALLAS13) or datacenter name (dal13)
+        :returns: integer id of the datacenter
+        """
+
+        if isinstance(location, int):
+            return location
+        mask = "mask[id,name,regions[keyname]]"
+        if match(r'[a-zA-Z]{3}[0-9]{2}', location) is not None:
+            search = {'name': {'operation': location}}
+        else:
+            search = {'regions': {'keyname': {'operation': location}}}
+        datacenter = self.client.call('SoftLayer_Location', 'getDatacenters', mask=mask, filter=search)
+        if len(datacenter) != 1:
+            raise exceptions.SoftLayerError("Unable to find location: %s" % location)
+        return datacenter[0]['id']
