@@ -252,18 +252,15 @@ class CLIAbortTests(testing.TestCase):
 class ResolveIdTests(testing.TestCase):
 
     def test_resolve_id_one(self):
-        resolver = lambda r: [12345]
-        self.assertEqual(helpers.resolve_id(resolver, 'test'), 12345)
+        self.assertEqual(helpers.resolve_id(lambda r: [12345], 'test'), 12345)
 
     def test_resolve_id_none(self):
-        resolver = lambda r: []
         self.assertRaises(
-            exceptions.CLIAbort, helpers.resolve_id, resolver, 'test')
+            exceptions.CLIAbort, helpers.resolve_id, lambda r: [], 'test')
 
     def test_resolve_id_multiple(self):
-        resolver = lambda r: [12345, 54321]
         self.assertRaises(
-            exceptions.CLIAbort, helpers.resolve_id, resolver, 'test')
+            exceptions.CLIAbort, helpers.resolve_id, lambda r: [12345, 54321], 'test')
 
 
 class TestTable(testing.TestCase):
