@@ -355,6 +355,116 @@ class VSTests(testing.TestCase):
 
         self.assertEqual(data, assert_data)
 
+    def test_generate_public_vlan_with_public_subnet(self):
+        data = self.vs._generate_create_dict(
+            cpus=1,
+            memory=1,
+            hostname='test',
+            domain='example.com',
+            os_code="STRING",
+            public_vlan=1,
+            public_subnet=1
+        )
+
+        assert_data = {
+            'startCpus': 1,
+            'maxMemory': 1,
+            'hostname': 'test',
+            'domain': 'example.com',
+            'localDiskFlag': True,
+            'operatingSystemReferenceCode': "STRING",
+            'hourlyBillingFlag': True,
+            'primaryNetworkComponent': {'networkVlan': {'id': 1,
+                                                        'primarySubnet': {'id': 1}}},
+            'supplementalCreateObjectOptions': {'bootMode': None},
+        }
+
+        self.assertEqual(data, assert_data)
+
+    def test_generate_private_vlan_with_private_subnet(self):
+        data = self.vs._generate_create_dict(
+            cpus=1,
+            memory=1,
+            hostname='test',
+            domain='example.com',
+            os_code="STRING",
+            private_vlan=1,
+            private_subnet=1
+        )
+
+        assert_data = {
+            'startCpus': 1,
+            'maxMemory': 1,
+            'hostname': 'test',
+            'domain': 'example.com',
+            'localDiskFlag': True,
+            'operatingSystemReferenceCode': "STRING",
+            'hourlyBillingFlag': True,
+            'primaryBackendNetworkComponent': {'networkVlan': {'id': 1,
+                                                               'primarySubnet': {'id': 1}}},
+            'supplementalCreateObjectOptions': {'bootMode': None},
+        }
+
+        self.assertEqual(data, assert_data)
+
+    def test_generate_private_vlan_subnet_public_vlan_subnet(self):
+        data = self.vs._generate_create_dict(
+            cpus=1,
+            memory=1,
+            hostname='test',
+            domain='example.com',
+            os_code="STRING",
+            private_vlan=1,
+            private_subnet=1,
+            public_vlan=1,
+            public_subnet=1,
+        )
+
+        assert_data = {
+            'startCpus': 1,
+            'maxMemory': 1,
+            'hostname': 'test',
+            'domain': 'example.com',
+            'localDiskFlag': True,
+            'operatingSystemReferenceCode': "STRING",
+            'hourlyBillingFlag': True,
+            'primaryBackendNetworkComponent': {'networkVlan': {'id': 1,
+                                                               'primarySubnet': {'id': 1}}},
+            'primaryNetworkComponent': {'networkVlan': {'id': 1,
+                                                        'primarySubnet': {'id': 1}}},
+            'supplementalCreateObjectOptions': {'bootMode': None},
+        }
+
+        self.assertEqual(data, assert_data)
+
+    def test_generate_private_subnet(self):
+        actual = self.assertRaises(
+            exceptions.SoftLayerError,
+            self.vs._generate_create_dict,
+            cpus=1,
+            memory=1,
+            hostname='test',
+            domain='example.com',
+            os_code="STRING",
+            private_subnet=1,
+        )
+
+        self.assertEqual(str(actual), "You need to specify a private_vlan with private_subnet")
+
+    def test_generate_public_subnet(self):
+        actual = self.assertRaises(
+            exceptions.SoftLayerError,
+            self.vs._generate_create_dict,
+            cpus=1,
+            memory=1,
+            hostname='test',
+            domain='example.com',
+            os_code="STRING",
+            public_subnet=1,
+        )
+
+        self.assertEqual(str(actual), "You need to specify a public_vlan with public_subnet")
+
     def test_generate_private_vlan(self):
         data = self.vs._generate_create_dict(
             cpus=1,
@@ -373,12 +483,73 @@ class VSTests(testing.TestCase):
             'localDiskFlag': True,
             'operatingSystemReferenceCode': "STRING",
             'hourlyBillingFlag': True,
-            'primaryBackendNetworkComponent': {"networkVlan": {"id": 1}},
+            'primaryBackendNetworkComponent': {'networkVlan': {'id': 1}},
             'supplementalCreateObjectOptions': {'bootMode': None},
         }
 
         self.assertEqual(data, assert_data)
 
+    def test_create_network_components_vlan_subnet_private_vlan_subnet_public(self):
+        data = self.vs._create_network_components(
+            private_vlan=1,
+            private_subnet=1,
+            public_vlan=1,
+            public_subnet=1,
+        )
+
+        assert_data = {
+            'primaryBackendNetworkComponent': {'networkVlan': {'id': 1,
+                                                               'primarySubnet': {'id': 1}}},
+            'primaryNetworkComponent': {'networkVlan': {'id': 1,
+                                                        'primarySubnet': {'id': 1}}},
+        }
+
+        self.assertEqual(data, assert_data)
+
+    def test_create_network_components_vlan_subnet_private(self):
+        data = self.vs._create_network_components(
+            private_vlan=1,
+            private_subnet=1,
+        )
+
+        assert_data = {
+            'primaryBackendNetworkComponent': {'networkVlan': {'id': 1,
+                                                               'primarySubnet': {'id': 1}}},
+        }
+
+        self.assertEqual(data, assert_data)
+
+    def test_create_network_components_vlan_subnet_public(self):
+        data = self.vs._create_network_components(
+            public_vlan=1,
+            public_subnet=1,
+        )
+
+        assert_data = {
+            'primaryNetworkComponent': {'networkVlan': {'id': 1,
+                                                        'primarySubnet': {'id': 1}}},
+        }
+
+        self.assertEqual(data, assert_data)
+
+    def test_create_network_components_private_subnet(self):
+        actual = self.assertRaises(
+            exceptions.SoftLayerError,
+            self.vs._create_network_components,
+            private_subnet=1,
+        )
+
+        self.assertEqual(str(actual), "You need to specify a private_vlan with private_subnet")
+
+    def test_create_network_components_public_subnet(self):
+        actual = self.assertRaises(
+            exceptions.SoftLayerError,
+            self.vs._create_network_components,
+            public_subnet=1,
+        )
+
+        self.assertEqual(str(actual), "You need to specify a public_vlan with public_subnet")
+
     def test_generate_userdata(self):
         data = self.vs._generate_create_dict(
             cpus=1,
@@ -708,6 +879,22 @@ class VSTests(testing.TestCase):
         self.assertIn({'id': 1122}, order_container['prices'])
         self.assertEqual(order_container['virtualGuests'], [{'id': 1}])
 
+    def test_upgrade_with_flavor(self):
+        # Testing Upgrade with parameter preset
+        result = self.vs.upgrade(1,
+                                 preset="M1_64X512X100",
+                                 nic_speed=1000,
+                                 public=True)
+
+        self.assertEqual(result, True)
+        self.assert_called_with('SoftLayer_Product_Order', 'placeOrder')
+        call = self.calls('SoftLayer_Product_Order', 'placeOrder')[0]
+        order_container = call.args[0]
+        self.assertEqual(799, order_container['presetId'])
+        self.assertIn({'id': 1}, order_container['virtualGuests'])
+        self.assertIn({'id': 1122}, order_container['prices'])
+        self.assertEqual(order_container['virtualGuests'], [{'id': 1}])
+
     def test_upgrade_dedicated_host_instance(self):
         mock = self.set_mock('SoftLayer_Virtual_Guest', 'getUpgradeItemPrices')
         mock.return_value = fixtures.SoftLayer_Virtual_Guest.DEDICATED_GET_UPGRADE_ITEM_PRICES
@@ -809,19 +996,6 @@ class VSWaitReadyGoTests(testing.TestCase):
         _sleep.assert_has_calls([mock.call(0)])
         self.assertFalse(value)
 
-    def test_active_reload(self):
-        # actively running reload
-        self.guestObject.side_effect = [
-            {'activeTransaction': {'id': 1}},
-            {
-                'activeTransaction': {'id': 1},
-                'provisionDate': 'aaa',
-                'lastOperatingSystemReload': {'id': 1},
-            },
-        ]
-        value = self.vs.wait_for_ready(1, 0)
-        self.assertFalse(value)
-
     def test_reload_no_pending(self):
         # reload complete, maintance transactions
         self.guestObject.return_value = {
